@@ -3,11 +3,11 @@
 """installObjectQueue script for the Zope 3 based
 ng.site.content.install package
 
-$Id: install_objectqueue.py 51965 2008-10-23 21:55:22Z cray $
+$Id: install_objectqueue.py 52301 2009-01-12 15:18:34Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51965 $"
+__version__ = "$Revision: 52301 $"
 
 from zope.app.file.interfaces import IImage
 from zope.app.file.image import Image
@@ -21,7 +21,9 @@ def installObjectQueue(context, **kw):
     sm = context.getSiteManager()
     
     oq = sm[u'objectqueue'] = ObjectQueue()
-    
+    oq.order = u'straight'    
+    oq.maxlen = 40
+
     sm.registerUtility(oq, provided=IObjectQueue)
 
     return "Success"
