@@ -11,5 +11,5 @@ def bannertuple(name,url,alt) :
     return (unicode(name),open(os.path.join(__path__[0],name)).read(),url,unicode(alt))
 
 banner_zope =  bannertuple('banner_zope.gif','http://www.zope.org','Zope')
-banner_thedream_whiteblue = bannertuple('banner_thedream_whiteblue.png','http://deambot.org','The Dream Bot Info Site')
+banner_thedream_whiteblue = bannertuple('banner_thedream_whiteblue.png','http://dreambot.ru','The Dream Bot Info Site')
 banners = [ banner_zope, banner_thedream_whiteblue]
\ No newline at end of file
