@@ -2,11 +2,11 @@
 #######################################################################
 """Adapter article to rss-entry
 
-$Id: article2rssentryadapter.py 51965 2008-10-23 21:55:22Z cray $
+$Id: article2rssentryadapter.py 52181 2008-12-25 11:15:40Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51965 $"
+__version__ = "$Revision: 52181 $"
 
 from zope.app.zapi import getUtility
 from zope.component import ComponentLookupError
@@ -19,7 +19,7 @@ import uuid
 from zope.app.zapi import getUtility
 from zope.app.catalog.interfaces import ICatalog
 from ng.adapter.adaptiveurl.adaptiveurl import adaptiveURL
-from ng.content.annotation.profileannotation.interfaces import IProfileAnnotation
+from ng.content.profile.profileannotation.interfaces import IProfileAnnotation
 
 class Article2RSSEntryAdapter(object) :
     """ Adapter article to rss-entry """
